@@ -5,11 +5,10 @@ TAR=../saxonhe_$VERSION+dfsg+1.orig.tar.xz
 DIR=saxonhe-$VERSION
 TAG="$VERSION"
 
-svn -q export https://www.saxonica.co.uk/repos/archive/opensource/tags/${TAG}/hej $DIR
+svn -q export https://dev.saxonica.com/repos/archive/opensource/tags/${TAG}/hej $DIR
 XZ_OPT=--best tar cJf $TAR \
  --exclude 'javax' \
- --exclude 'data/lib' \
- --exclude 'data/w3c' \
  --exclude 'net/sf/saxon/dotnet' \
+ --exclude 'net/sf/saxon/data/w3c' \
  --exclude 'net/sf/saxon/option' $DIR
 rm -rf $DIR ../$TAG
